Orchid.Repo behaviour (Orchid v0.5.6)

Copy Markdown View Source

Defines the behaviour of the data warehouse. Used to store large volumes of data unsuitable for direct transmission via Param (such as audio waveforms or model weights).

Implementation within Orchid is not currently envisaged, though other applications may implement this protocol and invoke it via custom hooks.

Summary

Types

key()

@type key() :: term()

opts()

@type opts() :: keyword()

value()

@type value() :: term()

Callbacks

delete(key)

@callback delete(key()) :: :ok | {:error, term()}

get(key)

@callback get(key()) :: {:ok, value()} | {:error, term()}

put(value, opts)

@callback put(value(), opts()) :: {:ok, key()} | {:error, term()}