Optional behaviour for adapters that support garbage collection (TTL expiry, LRU eviction, capacity-based pruning, etc.).
Summary
Callbacks
@callback garbage_collect(store :: Orchid.Repo.store_ref(), opts :: keyword()) :: :ok
Optional behaviour for adapters that support garbage collection (TTL expiry, LRU eviction, capacity-based pruning, etc.).
@callback garbage_collect(store :: Orchid.Repo.store_ref(), opts :: keyword()) :: :ok