Orchid.Step.ID (Orchid v0.6.1)

Copy Markdown View Source

Create identifier/fingerprint via Step's input, output or mapper in option.

Summary

Functions

normalize step's io key into MapSet.

Check if two steps have the same input and output keys.

Types

Functions

finger_print(step, headless? \\ true)

@spec finger_print(Orchid.Step.t(), headless? :: boolean()) :: t()

normalize_keys_to_set(atom)

@spec normalize_keys_to_set(nil | atom() | list() | tuple() | MapSet.t()) ::
  MapSet.t()

normalize step's io key into MapSet.

same?(step1, step2)

@spec same?(Orchid.Step.t(), Orchid.Step.t()) :: boolean()

Check if two steps have the same input and output keys.