Executor behavoir.
An executor receive a Orchid.Scheduler.Context struct and do execution.
There're some functions recommend to use during execution.
Summary
Functions
Executes the next ready step in the given context.
Types
@type executor() :: module()
@type executor_opts() :: keyword()
@type response() :: {:ok, Orchid.Scheduler.Context.param_map()} | {:error, Orchid.Error.t()}
Callbacks
@callback execute(Orchid.Scheduler.Context.t(), executor_opts()) :: response()
Functions
@spec execute_next_step(Orchid.Scheduler.Context.t()) :: {:done, Orchid.Scheduler.Context.t()} | {:stuck, Orchid.Scheduler.Context.t()} | {:cont, Orchid.Scheduler.Context.t()} | {:error, Orchid.Error.t()}
Executes the next ready step in the given context.
Debugging helper function for executors.