Create identifier/fingerprint via Step's input, output or mapper in option.
Summary
Functions
normalize step's io key into MapSet.
Check if two steps have the same input and output keys.
Types
@type t() :: {MapSet.t(Orchid.Step.input_keys()), MapSet.t(Orchid.Step.output_keys())} | {Orchid.Step.implementation(), MapSet.t(Orchid.Step.input_keys()), MapSet.t(Orchid.Step.output_keys())} | :root
Functions
@spec finger_print(Orchid.Step.t(), headless? :: boolean()) :: t()
normalize step's io key into MapSet.
@spec same?(Orchid.Step.t(), Orchid.Step.t()) :: boolean()
Check if two steps have the same input and output keys.